@@ -46,7 +46,9 @@ if __name__ == "__main__":
     print(f"float({bf1}) = {float(bf1)}")
     print(f"str({bf1}) = {str(bf1)}")
     print(f"str({bf3}) = {str(bf3)}")
-    print(f"Fraction({bf1}) = {bf1.fraction()}")
+    print(f"Fraction({bf1}) = {bf1.fraction}")
+    print(f"Binary({bf1}).fraction = {bf1.fraction}")
+    print(f"Binary({fl2}).string = {Binary(fl2).string}")
     print(f"{bf1} & {bf2} = {bf1&bf2}")
     print(f"{bf1} | {bf2} = {bf1|bf2}")
     print(f"{bf1} ^ {bf2} = {bf1^bf2}")
